---
search:
  exclude: true
---
# リリースプロセス/変更履歴

このプロジェクトは、形式 `0.Y.Z` を用いた semantic versioning をやや変更したバージョンに従います。先頭の `0` は、SDK がまだ急速に進化していることを示します。各コンポーネントの増分は以下のとおりです。

## マイナー（`Y`）バージョン

ベータとしてマークされていないパブリックインターフェースに対する **破壊的変更** の際に、マイナーバージョン `Y` を増やします。たとえば、`0.0.x` から `0.1.x` への変更には、破壊的変更が含まれる場合があります。

破壊的変更を避けたい場合は、プロジェクトで `0.0.x` バージョンにピン留めすることをおすすめします。

## パッチ（`Z`）バージョン

破壊的でない変更では `Z` を増やします:

- バグ修正
- 新機能
- プライベートインターフェースの変更
- ベータ機能の更新

## 破壊的変更の変更履歴

### 0.2.0

このバージョンでは、以前は引数として `Agent` を受け取っていた箇所のいくつかが、代わりに `AgentBase` を引数として受け取るようになりました。たとえば、MCP サーバーでの `list_tools()` 呼び出しです。これは型に関する変更のみであり、引き続き `Agent` オブジェクトを受け取ります。更新するには、`Agent` を `AgentBase` に置き換えて型エラーを修正してください。

### 0.1.0

このバージョンでは、[`MCPServer.list_tools()`][agents.mcp.server.MCPServer] に新しいパラメーター `run_context` と `agent` が追加されました。`MCPServer` を継承するすべてのクラスにこれらのパラメーターを追加する必要があります。